@@ -29,20 +29,20 @@ class SyncSolver:
     ----------
     page : Page
         The playwright page to solve the reCAPTCHA on.
-    retries : int, optional
-        The number of retries, by default 3.
+    attempts : int, optional
+        The number of solve attempts, by default 3.
 
     Attributes
     ----------
     token : Optional[str]
-        The reCAPTCHA token.
+        The g-recaptcha-response token.
 
     Methods
     -------
     close() -> None
         Remove the userverify response listener.
-    solve_recaptcha(retries: Optional[int] = None) -> str
-        Solve the reCAPTCHA and return the token.
+    solve_recaptcha(attempts: Optional[int] = None) -> str
+        Solve the reCAPTCHA and return the g-recaptcha-response token.
 
     Raises
     ------
@@ -54,13 +54,13 @@ class SyncSolver:
         If the reCAPTCHA could not be solved.
     """
 
-    def __init__(self, page: Page, retries: int = 3) -> None:
+    def __init__(self, page: Page, attempts: int = 3) -> None:
         self._page = page
-        self._retries = retries
+        self._attempts = attempts
         self.token: Optional[str] = None
 
     def __repr__(self) -> str:
-        return f"SyncSolver(page={self._page!r}, retries={self._retries!r})"
+        return f"SyncSolver(page={self._page!r}, attempts={self._attempts!r})"
 
     def __enter__(self) -> SyncSolver:
         return self
@@ -70,16 +70,16 @@ class SyncSolver:
 
     def _random_delay(self) -> None:
         """Delay the execution for a random amount of time between 1 and 4 seconds."""
-        self._page.wait_for_timeout(random.randint(1, 4) * 1000)
+        self._page.wait_for_timeout(random.randint(1000, 4000))
 
     def _extract_token(self, response: Response) -> None:
         """
-        Extract the reCAPTCHA token from the userverify response.
+        Extract the g-recaptcha-response token from the userverify response.
 
         Parameters
         ----------
         response : Response
-            The response to extract the token from.
+            The response to extract the g-recaptcha-response token from.
         """
         if re.search("/recaptcha/(api2|enterprise)/userverify", response.url) is None:
             return
@@ -115,11 +115,11 @@ class SyncSolver:
         if audio_challenge_button.is_visible():
             audio_challenge_button.click(force=True)
 
-        play_button = recaptcha_frame.get_by_role("button", name="Press PLAY to listen")
+        audio_challenge_text = recaptcha_frame.get_by_text("Press PLAY to listen")
         rate_limit = recaptcha_frame.get_by_text("Try again later")
 
         while True:
-            if play_button.is_visible():
+            if audio_challenge_text.is_visible():
                 break
 
             if rate_limit.is_visible():
@@ -208,29 +208,31 @@ class SyncSolver:
         except KeyError:
             pass
 
-    def solve_recaptcha(self, retries: Optional[int] = None) -> str:
+    def solve_recaptcha(self, attempts: Optional[int] = None) -> str:
         """
-        Solve the reCAPTCHA and return the token.
+        Solve the reCAPTCHA and return the g-recaptcha-response token.
 
         Parameters
         ----------
-        retries : Optional[int], optional
-            The number of retries, by default None
+        attempts : Optional[int], optional
+            The number of solve attempts, by default 3.
 
         Returns
         -------
         str
-            The reCAPTCHA token.
+            The g-recaptcha-response token.
 
         Raises
         ------
         RecaptchaNotFoundError
-            If the reCAPTCHA checkbox was not found.
+            If the reCAPTCHA was not found.
+        RecaptchaRateLimitError
+            If the reCAPTCHA rate limit has been exceeded.
         RecaptchaSolveError
             If the reCAPTCHA could not be solved.
         """
         self._page.on("response", self._extract_token)
-        retries = retries or self._retries
+        attempts = attempts or self._attempts
 
         self._page.wait_for_load_state("networkidle")
         recaptcha_frame = get_recaptcha_frame(self._page.frames)
@@ -240,13 +242,18 @@ class SyncSolver:
             raise RecaptchaNotFoundError
 
         recaptcha_checkbox.click(force=True)
+        audio_challenge_text = recaptcha_frame.get_by_text("Press PLAY to listen")
 
         audio_challenge_button = recaptcha_frame.get_by_role(
             "button", name="Get an audio challenge"
         )
 
         while True:
-            if audio_challenge_button.is_enabled():
+            if (
+                audio_challenge_text.is_visible()
+                or audio_challenge_button.is_visible()
+                and audio_challenge_button.is_enabled()
+            ):
                 break
 
             if recaptcha_checkbox.is_checked():
@@ -261,14 +268,14 @@ class SyncSolver:
             "button", name="Get a new challenge"
         )
 
-        while retries > 0:
+        while attempts > 0:
             self._random_delay()
             url = self._get_audio_url(recaptcha_frame)
             text = self._convert_audio_to_text(url)
 
             if text is None:
                 new_challenge_button.click()
-                retries -= 1
+                attempts -= 1
                 continue
 
             self._random_delay()
@@ -281,6 +288,6 @@ class SyncSolver:
                 return self.token
 
             new_challenge_button.click()
-            retries -= 1
+            attempts -= 1
 
         raise RecaptchaSolveError
